@@ -648,6 +648,18 @@
         <source>Gateway</source>
         <translation>Passarel·la</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Màscara de xarxa no vàlida</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Passarel·la no vàlida</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Adreça IP duplicada</translation>
+    </message>
 </context>
 <context>
     <name>SectionIPv6</name>
@@ -703,6 +715,18 @@
         <source>Gateway</source>
         <translation>Passarel·la</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Màscara de xarxa no vàlida</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Adreça IP duplicada</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Passarel·la no vàlida</translation>
+    </message>
 </context>
 <context>
     <name>SectionPPP</name>
