@@ -648,6 +648,18 @@
         <source>Gateway</source>
         <translation>Puerta de enlace</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Máscara de red inválida</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Puerta de enlace inválida</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Dirección IP duplicada</translation>
+    </message>
 </context>
 <context>
     <name>SectionIPv6</name>
@@ -703,6 +715,18 @@
         <source>Gateway</source>
         <translation>Puerta de enlace</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Máscara de red inválida</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Dirección IP duplicada</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Puerta de enlace inválida</translation>
+    </message>
 </context>
 <context>
     <name>SectionPPP</name>
