@@ -648,6 +648,18 @@
         <source>Gateway</source>
         <translation>Yhdyskäytävä</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Virheellinen verkkomaski</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Virheellinen yhdyskäytävä</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Päällekkäinen IP-osoite</translation>
+    </message>
 </context>
 <context>
     <name>SectionIPv6</name>
@@ -703,6 +715,18 @@
         <source>Gateway</source>
         <translation>Yhdyskäytävä</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Virheellinen verkkomaski</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Päällekkäinen IP-osoite</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Virheellinen yhdyskäytävä</translation>
+    </message>
 </context>
 <context>
     <name>SectionPPP</name>
