@@ -648,6 +648,18 @@
         <source>Gateway</source>
         <translation>ゲートウェイ</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>無効なネットマスクです</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>無効なゲートウェイです</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>IPアドレスが重複しています</translation>
+    </message>
 </context>
 <context>
     <name>SectionIPv6</name>
@@ -703,6 +715,18 @@
         <source>Gateway</source>
         <translation>ゲートウェイ</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>無効なネットマスクです</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>IPアドレスが重複しています</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>無効なゲートウェイです</translation>
+    </message>
 </context>
 <context>
     <name>SectionPPP</name>
