@@ -648,6 +648,18 @@
         <source>Gateway</source>
         <translation>Brama sieciowa</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Nieprawidłowa maska sieci</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Nieprawidłowa brama sieciowa</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Zduplikowany adres IP</translation>
+    </message>
 </context>
 <context>
     <name>SectionIPv6</name>
@@ -703,6 +715,18 @@
         <source>Gateway</source>
         <translation>Brama sieciowa</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Nieprawidłowa maska sieci</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Zduplikowany adres IP</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Nieprawidłowa brama sieciowa</translation>
+    </message>
 </context>
 <context>
     <name>SectionPPP</name>
@@ -1529,7 +1553,7 @@
     </message>
     <message>
         <source>Subject Match</source>
-        <translation type="unfinished"/>
+        <translation>Weryfikacja tożsamości</translation>
     </message>
     <message>
         <source>Remote Cert Type</source>
