@@ -648,6 +648,18 @@
         <source>Gateway</source>
         <translation>Gateway</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Máscara de sub-rede inválida</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Gateway inválido</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Endereço IP duplicado</translation>
+    </message>
 </context>
 <context>
     <name>SectionIPv6</name>
@@ -703,6 +715,18 @@
         <source>Gateway</source>
         <translation>Gateway</translation>
     </message>
+    <message>
+        <source>Invalid netmask</source>
+        <translation>Máscara de sub-rede inválida</translation>
+    </message>
+    <message>
+        <source>Duplicate IP address</source>
+        <translation>Endereço IP duplicado</translation>
+    </message>
+    <message>
+        <source>Invalid gateway</source>
+        <translation>Gateway inválido</translation>
+    </message>
 </context>
 <context>
     <name>SectionPPP</name>
