@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="fr">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fr">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Paramètres réseau</translation>
+        <translation>Paramètres réseau</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>Détection du réseau</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Désactivez d&apos;abord le &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Mode avion&lt;/a&gt; si vous souhaitez vous connecter à un réseau sans fil.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Conflit IP</translation>
+        <translation>Conflit d&apos;adresses IP</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Réseau</translation>
+        <translation>Réseau</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Connexion filaire %1</translation>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN L2TP %1</translation>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN PPTP %1</translation>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN VPNC %1</translation>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenVPN %1</translation>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN StrongSwan %1</translation>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenConnect %1</translation>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>PPPoE Connection %1</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Connexion à &quot;%1&quot;</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; connecté</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>&quot;%1&quot; déconnecté</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>Impossible de se connecter à &quot;%1&quot;, veuillez vérifier votre routeur ou votre câble réseau.</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>Impossible de se connecter à &quot;%1&quot;, veuillez vous rapprocher du routeur sans fil.</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Échec de la connexion, impossible de se connecter à &quot;%1&quot;, mot de passe incorrect.</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Un mot de passe est nécessaire pour se connecter à &quot;%1&quot;.</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>Le réseau WIFI 802.11 &quot;%1&quot; est introuvable.</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>Pour vous connecter à &quot;%1&quot;, veuillez configurer vos informations d&apos;authentification après vous être connecté.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Mot de passe</translation>
+        <translation>Mot de passe</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Mot de passe privé</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>clé</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Mot de passe du proxy</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Mot de passe du groupe</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Nom d&apos;utilisateur</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Nom (SSID)</translation>
+        <translation>Nom (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Annuler</translation>
+        <translation>Annuler</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Relier</translation>
+        <translation>Connecter</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Désactiver la connexion filaire</translation>
+        <translation>Désactiver la connexion filaire</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Activer la connexion filaire</translation>
+        <translation>Activer la connexion filaire</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Désactiver la connexion sans fil</translation>
+        <translation>Désactiver la connexion sans fil</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Activer la connexion sans fil</translation>
+        <translation>Activer la connexion sans fil</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Désactiver le réseau</translation>
+        <translation>Désactiver le réseau</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Activer le réseau</translation>
+        <translation>Activer le réseau</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Désactiver le VPN</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Activer le VPN</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Désactiver le proxy système</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Activer le proxy système</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Paramètres réseau</translation>
+        <translation>Paramètres réseau</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>Plusieurs services démarrés</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Connecté à : %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Proxy système activé</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">Connecté</translation>
+        <translation>Connecté</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Réseau désactivé</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Câble réseau débranché</translation>
+        <translation>Câble réseau débranché</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Pas connecté</translation>
+        <translation>Non connecté</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Connexion en cours</translation>
+        <translation>Connexion</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">Connecté mais pas d’accès internet</translation>
+        <translation>Connecté mais aucun accès à Internet</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">La connexion a échoué</translation>
+        <translation>Échec de la connexion</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Conflit IP</translation>
+        <translation>Conflit d&apos;IP</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Réseau sans fil</translation>
+        <translation>Réseau sans fil</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Connecté à %1</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Désactivé</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Réseau filaire</translation>
+        <translation>Réseau filaire</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Réseau</translation>
+        <translation>Réseau</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Proxy système</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>La configuration VPN n&apos;est pas connectée ou n&apos;a pas pu se connecter. Veuillez vous &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;rendre au centre de contrôle&lt;/a&gt; pour vérification.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Réseau filaire</translation>
+        <translation>Réseau filaire</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Réseau sans fil</translation>
+        <translation>Réseau sans fil</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Se connecter à un réseau caché</translation>
+        <translation>Se connecter à un réseau masqué</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Mes réseaux</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Autres réseaux</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Réseau</translation>
+        <translation>Réseau</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
