@@ -1,312 +1,310 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="sq">
+<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
 <context>
     <name>dde::network::DockContentWidget</name>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Rregullime rrjeti</translation>
+        <translation>Rregullime rrjeti</translation>
     </message>
     <message>
         <source>Network Detection</source>
-        <translation type="unfinished"></translation>
+        <translation>Pikasje Rrjeti</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetAirplaneModeTipsItem</name>
     <message>
         <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
-        <translation type="unfinished"></translation>
+        <translation>Nëse doni të lidheni me një rrjet pa fill, së pari çaktivizoni &lt;a href=&quot;Airplane Mode&quot;&gt;Mënyrën Aeroplan&lt;/a&gt;</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerPrivate</name>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Përplasje IP-sh</translation>
+        <translation>Përplasje IP-sh</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Rrjet</translation>
+        <translation>Rrjet</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetManagerThreadPrivate</name>
     <message>
         <source>Wired Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Lidhje Me Fill %1</translation>
     </message>
     <message>
         <source>VPN L2TP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN L2TP %1</translation>
     </message>
     <message>
         <source>VPN PPTP %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN PPTP %1</translation>
     </message>
     <message>
         <source>VPN VPNC %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN VPNC %1</translation>
     </message>
     <message>
         <source>VPN OpenVPN %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenVPN %1</translation>
     </message>
     <message>
         <source>VPN StrongSwan %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN StrongSwan %1</translation>
     </message>
     <message>
         <source>VPN OpenConnect %1</source>
-        <translation type="unfinished"></translation>
+        <translation>VPN OpenConnect %1</translation>
     </message>
     <message>
         <source>PPPoE Connection %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Lidhje PPPoE %1</translation>
     </message>
     <message>
         <source>Connecting &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Po lidhet me “%1”</translation>
     </message>
     <message>
         <source>&quot;%1&quot; connected</source>
-        <translation type="unfinished"></translation>
+        <translation>“%1” u lidh</translation>
     </message>
     <message>
         <source>&quot;%1&quot; disconnected</source>
-        <translation type="unfinished"></translation>
+        <translation>“%1” u shkëput</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
-        <translation type="unfinished"></translation>
+        <translation>S’arrihet të lidhet me “%1”, ju lutemi, kontrolloni rrugëzuesin tuaj ose kabllon e rrjetit.</translation>
     </message>
     <message>
         <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
-        <translation type="unfinished"></translation>
+        <translation>S’arrihet të lidhet me “%1”, ju lutemi, rrini më afër rrugëzuesit pa fill</translation>
     </message>
     <message>
         <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
-        <translation type="unfinished"></translation>
+        <translation>Lidhja dështoi, s’arrihet të lidhet me “%1”, fjalëkalim i gabuar</translation>
     </message>
     <message>
         <source>Password is required to connect &quot;%1&quot;</source>
-        <translation type="unfinished"></translation>
+        <translation>Për t’u lidhur me “%1”, lypset fjalëkalim</translation>
     </message>
     <message>
         <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
-        <translation type="unfinished"></translation>
+        <translation>Rrjeti 802.11 WLAN “%1” s’u gjet dot</translation>
     </message>
     <message>
         <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
-        <translation type="unfinished"></translation>
+        <translation>Që të bëhet lidhja me “%1”, ju lutemi, ujdisni hollësitë tuaja për mirëfilltësimin, pasi të bëni hyrjen</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSecretWidget</name>
     <message>
         <source>Password</source>
-        <translation type="unfinished">Fjalëkalim</translation>
+        <translation>Fjalëkalim</translation>
     </message>
     <message>
         <source>Private Pwd</source>
-        <translation type="unfinished"></translation>
+        <translation>Fjalëkalim Privat</translation>
     </message>
     <message>
         <source>key</source>
-        <translation type="unfinished"></translation>
+        <translation>kyç</translation>
     </message>
     <message>
         <source>Proxy Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Fjalëkalim Ndërmjetësi</translation>
     </message>
     <message>
         <source>Group Password</source>
-        <translation type="unfinished"></translation>
+        <translation>Fjalëkalim Grupi</translation>
     </message>
     <message>
         <source>Username</source>
-        <translation type="unfinished"></translation>
+        <translation>Emër përdoruesi</translation>
     </message>
     <message>
         <source>Name (SSID)</source>
-        <translation type="unfinished">Emër (SSID)</translation>
+        <translation>Emër (SSID)</translation>
     </message>
     <message>
         <source>Cancel</source>
         <comment>button</comment>
-        <translation type="unfinished">Anuloje</translation>
+        <translation>Anuloje</translation>
     </message>
     <message>
         <source>Connect</source>
         <comment>button</comment>
-        <translation type="unfinished">Lidhu</translation>
+        <translation>Lidhu</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetStatus</name>
     <message>
         <source>Disable wired connection</source>
-        <translation type="unfinished">Çaktivizo lidhje me fill</translation>
+        <translation>Çaktivizo lidhje me fill</translation>
     </message>
     <message>
         <source>Enable wired connection</source>
-        <translation type="unfinished">Aktivizo lidhje me fill</translation>
+        <translation>Aktivizo lidhje me fill</translation>
     </message>
     <message>
         <source>Disable wireless connection</source>
-        <translation type="unfinished">Çaktivizo lidhje pa fill</translation>
+        <translation>Çaktivizo lidhje pa fill</translation>
     </message>
     <message>
         <source>Enable wireless connection</source>
-        <translation type="unfinished">Aktivizo lidhje pa fill</translation>
+        <translation>Aktivizo lidhje pa fill</translation>
     </message>
     <message>
         <source>Disable network</source>
-        <translation type="unfinished">Çaktivizo rrjetin</translation>
+        <translation>Çaktivizo rrjetin</translation>
     </message>
     <message>
         <source>Enable network</source>
-        <translation type="unfinished">Aktivizo rrjetin</translation>
+        <translation>Aktivizo rrjetin</translation>
     </message>
     <message>
         <source>Disable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Çaktivizo VPN-në</translation>
     </message>
     <message>
         <source>Enable VPN</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktivizo VPN-në</translation>
     </message>
     <message>
         <source>Disable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Çaktivizo ndërmjetës sistemi</translation>
     </message>
     <message>
         <source>Enable system proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktivizo ndërmjetës sistemi</translation>
     </message>
     <message>
         <source>Network settings</source>
-        <translation type="unfinished">Rregullime rrjeti</translation>
+        <translation>Rregullime rrjeti</translation>
     </message>
     <message>
         <source>Multiple services started</source>
-        <translation type="unfinished"></translation>
+        <translation>U nisën shërbime të shumta</translation>
     </message>
     <message>
         <source>Connected to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation>I lidhur me: %1</translation>
     </message>
     <message>
         <source>System proxy enabled</source>
-        <translation type="unfinished"></translation>
+        <translation>Me ndërmjetës sistemi të aktivizuar</translation>
     </message>
     <message>
         <source>Connected</source>
-        <translation type="unfinished">E lidhur</translation>
+        <translation>E lidhur</translation>
     </message>
     <message>
         <source>Network off</source>
-        <translation type="unfinished"></translation>
+        <translation>Rrjeti off</translation>
     </message>
     <message>
         <source>Network cable unplugged</source>
-        <translation type="unfinished">Kablloja e rrjetit është e hequr</translation>
+        <translation>Kablloja e rrjetit është e hequr</translation>
     </message>
     <message>
         <source>Not connected</source>
-        <translation type="unfinished">Jo e lidhur</translation>
+        <translation>Jo e lidhur</translation>
     </message>
     <message>
         <source>Connecting</source>
-        <translation type="unfinished">Po lidhet</translation>
+        <translation>Po bëhet lidhja</translation>
     </message>
     <message>
         <source>Connected but no Internet access</source>
-        <translation type="unfinished">E lidhur, por pa hyrje Internet</translation>
+        <translation>E lidhur, por pa hyrje Internet</translation>
     </message>
     <message>
         <source>Connection failed</source>
-        <translation type="unfinished">Lidhja dështoi</translation>
+        <translation>Lidhja dështoi</translation>
     </message>
     <message>
         <source>IP conflict</source>
-        <translation type="unfinished">Përplasje IP-sh</translation>
+        <translation>Përplasje IP-sh</translation>
     </message>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Rrjet Pa Fill</translation>
+        <translation>Rrjet Pa Fill</translation>
     </message>
     <message>
         <source>Connected %1</source>
-        <translation type="unfinished"></translation>
+        <translation>Po lidhet me %1</translation>
     </message>
     <message>
         <source>Off</source>
-        <translation type="unfinished"></translation>
+        <translation>Off</translation>
     </message>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Rrjet Me Fill</translation>
+        <translation>Rrjet Me Fill</translation>
     </message>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Rrjet</translation>
+        <translation>Rrjet</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetSystemProxyControlItem</name>
     <message>
         <source>System Proxy</source>
-        <translation type="unfinished"></translation>
+        <translation>Ndërmjetës Sistemi</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetVPNTipsItem</name>
     <message>
         <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
-        <translation type="unfinished"></translation>
+        <translation>Formësimi i VPN-së s’u përdor, ose s’u arrit të bëhet lidhje. Ju lutemi, për të parë se si është puna, &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;kaloni te qendër kontrolli&lt;/a&gt;.</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWiredControlItem</name>
     <message>
         <source>Wired Network</source>
-        <translation type="unfinished">Rrjet Me Fill</translation>
+        <translation>Rrjet Me Fill</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessControlItem</name>
     <message>
         <source>Wireless Network</source>
-        <translation type="unfinished">Rrjet Pa Fill</translation>
+        <translation>Rrjet Pa Fill</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessHiddenItem</name>
     <message>
         <source>Connect to hidden network</source>
-        <translation type="unfinished">Lidhu me rrjet të fshehur</translation>
+        <translation>Lidhu në rrjet të fshehur</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessMineItem</name>
     <message>
         <source>My Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Rrjetet e Mi</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetWirelessOtherItem</name>
     <message>
         <source>Other Networks</source>
-        <translation type="unfinished"></translation>
+        <translation>Rrjete të Tjerë</translation>
     </message>
 </context>
 <context>
     <name>dde::network::NetworkPlugin</name>
     <message>
         <source>Network</source>
-        <translation type="unfinished">Rrjet</translation>
+        <translation>Rrjet</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
